import { store } from "/@/store";
import { router } from "/@/router";
import { defineStore } from "pinia";
import { userType, resType } from "./types";
import { routerArrays } from "/@/layout/types";
import { storageSession } from "@pureadmin/utils";
import { useMultiTagsStoreHook } from "/@/store/modules/multiTags";

import { getRelaComNo, setRelaComName, removeRelaComNo } from "/@/utils/auth";
import { ElMessage } from "element-plus";

import { loadEnv } from "@build/index";

const { VITE_IS_PROD } = loadEnv();

import {
  getLogin,
  getAsyncRoutes,
  ddDetail,
  refreshToken,
  httpCompany,
  httpUserInfo,
  httpSystemLast
} from "/@/api/user";

import {
  getToken,
  setToken,
  setRelaComNo,
  removeToken,
  getAction,
  setAction,
  removeAction
} from "/@/utils/auth";

import { removeMenus } from "/@/store/modules/permission";
import { trigger } from "/@/plugins/errorHooks/trigger";

export const useUserStore = defineStore({
  id: "pure-user",
  state: (): userType => ({
    token: getToken(),
    level: "0",
    name: "admin",
    // 前端生成的验证码（按实际需求替换）
    verifyCode: "",
    // 登录显示组件判断 0：登录 1：手机登录 2：二维码登录 3：注册 4：忘记密码，默认0：登录
    currentPage: 0,
    menuActions: getAction(),
    companyList: [],
    currentCompany: null,
    isSuperUser: false,
    swithingCompany: false,
    disabledCompany: false,
    systemInfo: {},
    info: {}
  }),
  actions: {
    SET_TOKEN(token) {
      this.token = token;
    },
    SET_NAME(name) {
      this.name = name;
    },

    SET_LEVEL(level) {
      this.level = level;
    },

    SET_VERIFYCODE(verifyCode) {
      this.verifyCode = verifyCode;
    },
    SET_CURRENTPAGE(value) {
      this.currentPage = value;
    },
    SET_ACTIONS(value) {
      this.actions = value;
    },
    SET_CURRENT_COMPANY(currentCompany) {
      this.currentCompany = currentCompany;
    },
    // 登入
    async loginByUsername(form) {
      return new Promise((resolve, reject) => {
        getLogin(form)
          .then((res: resType) => {
            const { code, data } = res;
            if (code === 0) {
              const { token, companyNo, company_name } = data;
              // setRelaComNo(companyNo);
              // setRelaComName(company_name);
              setToken(token);
              resolve(res);
            } else {
              resolve(res);
            }
          })
          .catch(error => {
            reject(error);
          });
      });
    },
    async loginByToken(token) {
      setToken(token);
      await this.postMenuList();
    },
    //钉钉code 获取用户账号详情
    dingUserInfor(code) {
      return new Promise((resolve, reject) => {
        ddDetail(code)
          .then((res: resType) => {
            const { code, data } = res;
            if (code === 0) {
              const { token, companyNo } = data;
              setToken(token);
              setRelaComNo(companyNo);
              resolve(res);
            } else {
              resolve("error");
            }
          })
          .catch(error => {
            reject(error);
          });
      });
    },
    async requesetUserInfo() {
      const { code, data, message } = await httpUserInfo({
        noRela: true
      });

      this.info = data;
      if (Number(code) === 0) {
        const { role_level, level } = data;

        /** 没有设置过level  */
        if (this.level === "0" || !this.level) {
          this.level = level;
        }

        this.isSuperUser = role_level === "1";

        if (!this.isSuperUser && this.companyList.length === 0) {
          const { data: companyData } = await httpCompany({ size: 10000 });

          this.companyList = companyData.list;
          if (!this.companyList || this.companyList.length === 0) {
            return;
          }
        }
        const code = getRelaComNo();

        const index = this.companyList.findIndex(
          ({ companyNo, companyCode }) =>
            companyNo === code || companyCode === code
        );

        let _index = index >= 0 ? index : -1;

        if (_index === -1) {
          _index = this.companyList.findIndex(
            ({ is_main }) => String(is_main) === "1"
          );
        }

        const currentCompany = !this.isSuperUser
          ? this.companyList[_index === -1 ? 0 : _index]
          : "";

        if (currentCompany && currentCompany.companyCode) {
          currentCompany.companyNo = currentCompany.companyCode;
        }

        this.currentCompany = currentCompany;
        setRelaComName(currentCompany.companyName);
        setRelaComNo(currentCompany.companyNo);
      } else {
        throw new Error(JSON.stringify({ code, message }));
      }
    },

    async requsetSystemInfo() {
      const { data, code } = await httpSystemLast({});
      if (Number(code) === 0) {
        this.systemInfo = data;
      } else {
        throw new Error();
      }
    },
    // 获取当前账号菜单数据
    async postMenuList(form) {
      try {
        await this.requesetUserInfo();
        await this.requsetSystemInfo();

        return new Promise((resolve, reject) => {
          getAsyncRoutes(form)
            .then((res: resType) => {
              const { code, data, message } = res;

              const { id } = this.info;

              let systemList = [];

              if (VITE_IS_PROD === "true") {
                systemList = ["109", "44", "37", "36"];
              }

              if (VITE_IS_PROD === "false") {
                systemList = ["109", "44", "37", "36"];
              }

              if (!systemList.includes(id)) {
                res.data = res.data.filter(
                  ({ menu_name }) => menu_name !== "系统设置" && menu_name !== "业务公司账号权限" && menu_name !== ""
                );
              }

              if (message === "账户已禁用") {
                removeMenus();
                reject(10000);
                trigger("roleException");
                return;
              }

              const actionList: Array<any> = [];
              switch (Number(code)) {
                case 0:
                  data.forEach(e => {
                    e.child?.forEach(s => {
                      const item = {
                        menu_route: s.menu_route,
                        action: s.action
                      };
                      actionList.push(item);
                    });
                  });
                  setAction(JSON.stringify(actionList));
                  resolve(res);
                  break;
                case 10000:
                  removeMenus();
                  reject(10000);
                  trigger("roleException");
                  return;
                default:
                  resolve(res);
                  break;
              }
              this.disabledCompany = false;
            })
            .catch(error => {
              reject(error);
            });
        });
      } catch (err) {
        if (err && err.message) {
          const { code, message } = JSON.parse(err.message);
          if (!(Number(code) >= 100 && Number(code) <= 104)) {
            ElMessage.error(message);
          }

          // if (code === "userExcption") {
          //   trigger("userExcption");
          //   return;
          // }
        }

        window.location.hash = "login";
      }
    },
    // 登出 清空缓存
    logOut() {
      this.token = "";
      this.name = "";
      this.level = "";
      removeToken();
      removeAction();
      storageSession.clear();
      this.currentComapny = "";
      this.companyList = [];
      removeRelaComNo();
      useMultiTagsStoreHook().handleTags("equal", routerArrays);
      router.push("/login");
    },
    // 刷新token
    async refreshToken(data) {
      return refreshToken(data).then(data => {
        if (data) {
          setToken(data);
          return data;
        }
      });
    },
    getMenuActions(code) {
      const arr = getAction();
      if (arr && arr.length > 0) {
        const powerHook = JSON.parse(arr);
        const arr1 = powerHook.find(i => i.menu_route == code)?.action || [];
        return arr1;
      } else {
        return [];
      }
    }
  }
});

export async function initalUser() {
  return useUserStore().requesetUserInfo();
}

export function useUserStoreHook() {
  return useUserStore(store);
}
