import { h } from "vue";
import { ElImage, ElTag } from "element-plus";
import { createTooltip } from "/@/utils/tootip";

import { verification, required } from "/@/utils/verification";

export const diffCatOptions = [
  { value: "0", label: "无" },
  { value: "1", label: "类目一致" },
  { value: "2", label: "类目不一致" }
];

export const diffTaxOptions = [
  { value: "0", label: "无" },
  { value: "1", label: "税率一致" },
  { value: "2", label: "税率不一致" }
];

export const good_type = [
  {
    value: "0",
    label: "待采购设置"
  },
  {
    value: "1",
    label: "待财务设置"
  },
  {
    value: "2",
    label: "已设置完成"
  }
];

export const stock_type = [
  {
    value: "0",
    label: "非库存"
  },
  {
    value: "1",
    label: "库存"
  }
];

//类目新增校验规则
export const cost_rules = verification(
  required("tax", "请选择税率"),
  required("cat_code", "请选择类目"),
  required("inv_tag", "请选择税率标识"),
  required("addTax", "请选择增值税管理内容"),
  required("inv_good_name", "请选择商品名称"),
  required("is_discount", "请选择是否包含优惠政策")
);

export const good_detail_columns = [
  {
    field: "spuCode",
    span: 6,
    label: "商品编码"
  },
  {
    field: "good_name",
    span: 18,
    label: "商品名称"
  },
  {
    label: "商品类目(修改前)",
    span: 12,
    render(_, row) {
      return row.before.inv_cat_name ? row.before.inv_cat_name : "--";
    }
  },
  {
    label: "商品类目(修改后)",
    span: 12,
    render(_, row) {
      return row.after.inv_cat_name ? row.after.inv_cat_name : "--";
    }
  },
  {
    label: "商品税率(修改前)",
    span: 12,
    render(_, row) {
      return row.before.inv_tax ? row.before.inv_tax : "--";
    }
  },
  {
    label: "商品税率(修改后)",
    span: 12,
    render(_, row) {
      return row.after.inv_tax ? row.after.inv_tax : "--";
    }
  },
  {
    label: "是否有优惠政策(修改前)",
    span: 12,
    render(_, row) {
      return row.before.is_discount ? mapDiscount[row.before.is_discount] : "--";
    }
  },
  {
    label: "是否有优惠政策(修改后)",
    span: 12,
    render(_, row) {
      return row.after.is_discount ? mapDiscount[row.after.is_discount] : "--";
    }
  },
  {
    label: "增值税管理内容(修改前)",
    span: 12,
    render(_, row) {
      return row.before.addTax || row.before.addTax === "" ? row.before.addTax : "--";
    }
  },
  {
    label: "增值税管理内容(修改后)",
    span: 12,
    render(_, row) {
      return row.after.addTax || row.after.addTax === "" ? row.after.addTax : "--";
    }
  },
  {
    label: "税率标识(修改前)",
    span: 12,
    render(_, row) {
      return row.before.inv_tag || row.before.inv_tag === "" ? mapTag[row.before.inv_tag] : "--";
    }
  },
  {
    label: "税率标识(修改后)",
    span: 12,
    render(_, row) {
      return row.after.inv_tag || row.after.inv_tag === "" ? mapTag[row.after.inv_tag] : "--";
    }
  }
];


const mapDiscount = {
  "1": "是",
  "0": "否"
};

const mapTag = {
  "1": "免税",
  "2": "不征税",
  "3": "零税率"
};

export const inv_tag = [
  // {
  //   value: "0",
  //   label: "非零税率"
  // },
  {
    value: "1",
    label: "免税"
  },
  {
    value: "2",
    label: "不征税"
  },
  {
    value: "3",
    label: "零税率"
  }
];

export const add_tax = [
  {
    value: "免税",
    label: "免税"
  },
  {
    value: "不征税",
    label: "不征税"
  }
];
