import { ContentConfig } from "/@/components/PageContent";
import { httpChangeList } from "/@/api/InvoiceSaleSettings/commodityCost";

import { h } from "vue";
import dayjs from "dayjs";
import { ElImage, ElTag } from "element-plus";
import { good_type } from "./configs";
import { renderIconLabelLeft } from "/@/utils/columnRenderHelper";

function renderGoodImage(imgSrc: string) {
  const imgs = imgSrc.split(",");
  return h(ElImage, {
    src: imgs[0],
    previewTeleported: true,
    previewSrcList: [imgs[0]],
    style: {
      height: "20px",
      width: "20px"
    }
  });
}

const columns = [
  {
    width: 40,
    type: "selection",
    align: "center",
    fixed: "left"
  },
  {
    label: "商品编码",
    prop: "spuCode",
    width: 150
  },
  {
    label: "商品名称",
    prop: "good_name",
    minWidth: 195
  },
  {
    label: "商品类型",
    prop: "isZx",
    width: 120,
    cellRenderer({ row }) {
      return row.isZx == 1 ? "咨询商品" : "成本商品";
    },
  },
  {
    label: "卖出方公司",
    prop: "supplierName",
    width: 175,
    ...renderIconLabelLeft("supplierNo", "supplierName", "卖出方公司编码:")
  },
  {
    label: "买入方公司",
    prop: "companyName",
    width: 195,
    ...renderIconLabelLeft("companyNo", "companyName", "买入方公司编码:")
  },
  {
    label: "主图",
    prop: "good_img",
    width: 55,
    cellRenderer: ({ row }) => renderGoodImage(row.good_img)
  },
  {
    label: "操作",
    fixed: "right",
    width: 80,
    slot: "operation"
  }
];

const contentConfig: ContentConfig = {
  columns,
  apis: {
    httpList: httpChangeList
  }
};

export default contentConfig;
